platform: Add function to detect the panel and pick up corresponding DT

For 8909, add function to detect the panel as HD/qHD based on the value
read from a register and update the bits 11:12 of the hlos_subtype
accordingly, so as to pick the correct DT.

Change-Id: Ic2e3b053c6423afe5c6604c3d6b84fd0a54dc027
diff --git a/platform/msm_shared/board.c b/platform/msm_shared/board.c
index 3b2493d..89fb195 100644
--- a/platform/msm_shared/board.c
+++ b/platform/msm_shared/board.c
@@ -236,11 +236,11 @@
 		}
 
 		/* HLOS subtype
 		 * bit no                        |31    20 | 19        16| 15          8 | 7     0|
 		 * board.platform_hlos_subtype = |reserved | Boot device | DDR detection | subtype|
 		 *                               |  bits   |             |   bits        |
 		 */
-		board.platform_hlos_subtype = (board_get_ddr_subtype() << 8) | (platform_get_boot_dev() << 16);
+		board.platform_hlos_subtype = (board_get_ddr_subtype() << 8) | (platform_get_boot_dev() << 16) | (platform_detect_panel() << 11);
 	}
 	else
 	{
@@ -236,11 +236,11 @@
 
 		/* HLOS subtype
-		 * bit no                        |31    20 | 19        16| 15          8 | 7     0|
-		 * board.platform_hlos_subtype = |reserved | Boot device | DDR detection | subtype|
-		 *                               |  bits   |             |   bits        |
+		 * bit no                        |31    20 | 19        16|15    13 |12      11 | 10          8 | 7     0|
+		 * board.platform_hlos_subtype = |reserved | Boot device |Reserved | Panel     | DDR detection | subtype|
+		 *                               |  bits   |             |  bits   | Detection |
 		 */